import request from '@/axios'

export const getRoleListApi = () => {
  return request.get({ url: '/tenant/sysRole/getRolePageList',params:{
    currentPage:1,
    pageSize:200
  }})
}
export const deleteRoleByIdApi = (id) => {
  console.log(id)
  return request.post({
    url: '/tenant/sysRole/deleteRoleById',
    params: {
      id
    }
  })
}

export const updateRoleAndMenusByIdApi = (id,name, remark = '', menuIds) => {
  return request.post({
    url: '/tenant/sysRole/updateRoleAndMenusById',
    data: {
      id,
      name,
      remark,
      menuIds
    }
  })
}


export const addRoleAndAssignMenusApi = (name, remark = '', menuIds) => {
  return request.post({
    url: '/tenant/sysRole/addRoleAndAssignMenus',
    data: {
      name,
      remark,
      menuIds
    }
  })
}

// 启用单个角色
export const enableRoleSingleApi = (id) => {
  return request.post({
    url: '/tenant/sysRole/enableRoleSingle',
    params: {
      id
    }
  });
};

// 禁用单个角色
export const disableRoleSingleApi = (id) => {
  return request.post({
    url: '/tenant/sysRole/disableRoleSingle',
    params: {
      id
    }
  });
};

// 根据角色id查询菜单树
export const getMenuTreeByRoleIdApi = (roleId) => {
  return request.get({
    url: '/tenant/sysRole/getMenuTreeByRoleId',
    params: {
      roleId
    }
  });
};


/**
 * 更新角色和角色下菜单
 * @param {Object} params - 请求参数
 * @param {number} [params.id] - 主键 id
 * @param {string} params.name - 角色名称，必需
 * @param {string} [params.remark] - 角色描述
 * @param {number[]} [params.menuIds] - 菜单 id 集合
 * @returns {Promise} - 返回一个 Promise 对象
 */
export const assignMenusToRoleApi = (params) => {
  // 检查必需参数 name 是否存在
  if (!params.name) {
    throw new Error('角色名称是必需的参数');
  }

  return request.post({
    url: '/tenant/sysRole/updateRoleAndMenusById',
    data: params, // 使用 data 传递 application/json 格式的请求体
  });
};