import { defineStore } from 'pinia'
import { store } from '../index'
import { UserLoginType, UserType } from '@/api/login/types'
import { ElMessageBox } from 'element-plus'
import { useI18n } from '@/hooks/web/useI18n'
import { loginOutApi } from '@/api/login'
import { useTagsViewStore } from './tagsView'
import {getUserInfoApi} from '@/api/user'
import router from '@/router'

interface UserState {
  userInfo?: UserType
  tokenKey: string
  token: string
  roleRouters?: string[] | AppCustomRouteRecordRaw[]
  rememberMe: boolean
  loginInfo?: UserLoginType,
  userRoles:string[],
  tenantPhone:string 
}

  export const useUserStore = defineStore('user', {
    state: (): UserState => {
      return {
        userInfo: undefined,
        tokenKey: 'Authorization',
        token: '',
        roleRouters: undefined,
        // 记住我
        rememberMe: true,
        loginInfo: undefined,
        userRoles:[],
        tenantPhone:'',
      }
    },
    getters: {
      getTokenKey(): string {
        return this.tokenKey
      },
      getToken(): string {
        return this.token
      },
      getUserInfo(): UserType | undefined {
        return this.userInfo
      },
      getRoleRouters(): string[] | AppCustomRouteRecordRaw[] | undefined {
        return this.roleRouters
      },
      getRememberMe(): boolean {
        return this.rememberMe
      },
      getLoginInfo(): UserLoginType | undefined {
        return this.loginInfo
      },
      getUserRoles():string[]{
        return this.userRoles
      }
    },
    actions: {
      setTokenKey(tokenKey: string) {
        this.tokenKey = tokenKey
      },
      setToken(token: string) {
        this.token = token
      },
      setUserInfo(userInfo?: UserType) {
        this.userInfo = userInfo
      },
      setUserRoles(Roles:string[]){
        this.userRoles = Roles
      },
      setRoleRouters(roleRouters: string[] | AppCustomRouteRecordRaw[]) {
        this.roleRouters = roleRouters
      },
      logoutConfirm() {
        const { t } = useI18n()
        ElMessageBox.confirm(t('common.loginOutMessage'), t('common.reminder'), {
          confirmButtonText: t('common.ok'),
          cancelButtonText: t('common.cancel'),
          type: 'warning'
        })
          .then(async () => {
            this.reset()

            // const res = await loginOutApi().catch(() => {})
            // if (res) {
            //   this.reset()
            // }
          })
          .catch(() => {})
      },
      reset() {
        const tagsViewStore = useTagsViewStore()
        tagsViewStore.delAllViews()
        this.setToken('')
        this.setUserInfo(undefined)
        this.setRoleRouters([])
        console.log('回到login')
        router.replace('/login')
      },
      logout() {
        this.reset()
      },
      setRememberMe(rememberMe: boolean) {
        this.rememberMe = rememberMe
      },
      setLoginInfo(loginInfo: UserLoginType | undefined) {
        this.loginInfo = loginInfo
      },
      // 获取用户信息
      async reqUserInfo(){
        return new Promise(async ()=>{
          const {data} = await getUserInfoApi()
          const {menuTreeVo} = data || {}
          const rou = this.roleRouters ?? []
          this.setRoleRouters([...rou,...menuTreeVo])
          console.log('用户信息：',data)
        })
      }
    },
    persist: true,

  })

export const useUserStoreWithOut = () => {
  return useUserStore(store)
}
